#!/bin/bash

# just in case
ulimit -s unlimited

# load things
module purge
module load python/3.7.0-anaconda3-2018.12 
. /sw/dtn/python/3.7/anaconda3/2018.12/etc/profile.d/conda.sh
conda activate lwsspy


export OPENBLAS_NUM_THREADS=1

# Run inversion exectubale
submissiondir="/ccs/home/lsawade/SI_depth_hypo_damping_2"

cmtdir="${submissiondir}/cmtsolutions"
submitteddir="${submissiondir}/submitted"
downloadeddir="${submissiondir}/downloaded"
downloadfaildir="${submissiondir}/downloadfail"
donedir="${submissiondir}/done"
faildir="${submissiondir}/fail"
inputfile="${submissiondir}/input.yml"

cmtsolutions=$(ls $cmtdir)

# to be filled arrays
pids=()
cmts=()

# Maximum number of downloads
MAXDL=2

# Add a counter
counter=0

for cmt in $cmtsolutions
do
    # Get CMT solution
    cmtsolution=$cmtdir/${cmt}

    # Run inversion
    # echo $cmtsolution
    invert-cmt $cmtsolution -i $inputfile -d

    # store PID of process
    pids+=("$!")

    # Store cmt 
    cmts+=("${cmt}")
    
    counter=$((counter+1))
    
    if [[ "$counter" -gt "$MAXDL" ]]; then
	break
    fi
done

# Add a counter
counter=0

# Check status
for i in ${!pids[@]}; do

    if wait ${pids[$i]}; then

	echo ${cmts[$i]} SUCCESS

    	# Copy cmt to done 
    	cp $cmtsolution $downloadeddir/${cmts[$i]}

    else
	echo ${cmtsolutions[$i]} FAIL

	# Copy cmt to done 
	cp $cmtsolution $downloadfaildir/${cmts[$i]}

    fi
    
    counter=$((counter+1))

    if [[ "$counter" -gt "$MAXDL" ]]; then
	break
    fi
    
done
