import os
import glob
import lwsspy as lpy
from obspy import UTCDateTime

from random import random
from time import sleep

def randsleep():
    sleep(0.5*random() + 0.5)

def write_filtered_catalog(original, catalog_params_file: str, outdir: str):

    filterdicts = lpy.read_yaml_file(catalog_params_file)
    
    if verbose:
        print(filterdicts)

    # Check if mindict in the yaml file
    if "mindict" in filterdicts:

        # Assign the dict
        mindict = filterdicts["mindict"]

        # Get timestamp to UTC
        if "origin_time" in mindict:
            mindict["origin_time"] = UTCDateTime(mindict["origin_time"])

    else:
        mindict = None


    # Check if mindict in the yaml file
    if "maxdict" in filterdicts:

        # Assign the dict
        maxdict = filterdicts["maxdict"]

        # Get timestamp to UTC
        if "origin_time" in mindict:
            maxdict["origin_time"] = UTCDateTime(maxdict["origin_time"])

    else:
        maxdict = None
        
    # Check
    if verbose:
        print("Max")
        print(maxdict)

    if verbose:
        print("Min")
        print(mindict)


    cat = lpy.CMTCatalog.load(catalog)
    filtered_cat = cat.filter(maxdict=maxdict, mindict=mindict)

    if verbose:
        print("Original:", len(cat))
        print("Filtered:", len(filtered_cat))

    # Sort the catalog
    filtered_cat.sort(key='eventname')

    # Write 
    filtered_cat.cmts2dir(outdir=outdir)
    


def check_submission(cmtdir: str, submissiondir: str, verbose: bool = False):
    
    # Check cmts
    cmts = sorted(os.listdir(cmtdir))

    # Check with IDs already submitted
    submittedcmts = os.listdir(submissiondir)

    # Check whether in submission directory
    for event in cmts:
        event
        if event in submittedcmts:
            continue
        else:
            event_to_be_submitted = event
            break

    if "event_to_be_submitted" not in locals():
        if verbose:
            print("No events left to be submitted")
        
        return "DONE"

    else:
        if verbose:
            print("Next:", event_to_be_submitted)
        
        return event_to_be_submitted


if __name__ == "__main__":
    
    import sys

    cmtdir = sys.argv[1]
    submitteddir = sys.argv[2]

    catalog = "gcmtcatalog.pkl"
    catalog_params_file = "catalog_params.yml"
    outdir = "filteredcmtsolutions"
    
    # cmtdir = "cmtsolutions"
    # submissiondir = "submitted"
    
    
    print(check_submission(cmtdir, submitteddir))
    
