import os
import glob
import lwsspy as lpy
from obspy import UTCDateTime

def write_filtered_catalog(original, catalog_params_file: str, outdir: str, verbose: bool =True):
    
    filterdicts = lpy.read_yaml_file(catalog_params_file)
    
    if verbose:
        print(filterdicts)
    
    if filterdicts is None:
        filterdicts = dict()

    # Check if mindict in the yaml file
    if "mindict" in filterdicts:

        # Assign the dict
        mindict = filterdicts["mindict"]

        # Get timestamp to UTC
        if "origin_time" in mindict:
            mindict["origin_time"] = UTCDateTime(mindict["origin_time"])

    else:
        mindict = None


    # Check if mindict in the yaml file
    if "maxdict" in filterdicts:

        # Assign the dict
        maxdict = filterdicts["maxdict"]

        # Get timestamp to UTC
        if "origin_time" in mindict:
            maxdict["origin_time"] = UTCDateTime(maxdict["origin_time"])

    else:
        maxdict = None
        
    # Check
    if verbose:
        print("Max")
        print(maxdict)

    if verbose:
        print("Min")
        print(mindict)

    # Load catalog
    cat = lpy.CMTCatalog.load(catalog)

    # Load
    if maxdict is None and mindict is None:
        filtered_cat = cat
    else:
        filtered_cat = cat.filter(maxdict=maxdict, mindict=mindict)

    if verbose:
        print("Original:", len(cat))
        print("Filtered:", len(filtered_cat))

    # Sort the catalog
    filtered_cat.sort(key='eventname')

    # Write 
    filtered_cat.cmts2dir(outdir=outdir)


if __name__ == "__main__":
    
    import sys

    catalog = "gcmtcatalog.pkl"
    catalog_params_file = "catalog_params.yml"
    outdir = "cmtsolutions"
        
    write_filtered_catalog(catalog, catalog_params_file, outdir)
    
    
