#!/bin/bash
#SBATCH -N1
#SBATCH -t02:00:00
#SBATCH -A GEO111 
#SBATCH --mem=50GB
#SBATCH --output=output.plot_meas

# just in case
ulimit -s unlimited

# load things
module purge
module load emacs python/3.7-anaconda3
. /sw/andes/python/3.7/anaconda-base/etc/profile.d/conda.sh

conda activate lwsspy_andes

PICKLES=false
MT=true
MT_CORR=true
DEPTH=true
DEPTH_CORR=true
FINAL=true

# Main directory for the stats
MAINDIR=/gpfs/alpine/geo111/scratch/lsawade/stats
CATALOGS=${MAINDIR}/catalogs
# -------------------------- Single Iteration -----------------------------------------

if [ "$MT" = true ]; then

    echo 'Summarizing results for single iteration ...'
  
    # Set vairables
    INVDATABASE=/gpfs/alpine/geo111/scratch/lsawade/testdatabase_mt_si_hypo_damping_2

    # Outdir
    OUTDIR=${MAINDIR}/single_iteration

    # File label
    BEFORE=before
    AFTER=after

    BEFORE_LABEL=GCMT
    AFTER_LABEL=GCMT3D

    # Fix database
    if [ "$PICKLES" = true ]; then
	echo Creating the database pickles ...
	gcmt3d-plot-measurement-histograms \
	    -d $INVDATABASE -o $OUTDIR -a $AFTER -b $BEFORE -m dlna
    fi


    echo Plotting ...
    # dlnA
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m dlna
    # Chi
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m chi
    # tshift
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m time_shift

    # Catalog comparison
    compare-catalogs \
	-o $CATALOGS/gcmt.pkl \
	-n $CATALOGS/gcmt3d.pkl \
	-d $OUTDIR \
	-w \
	-ol $BEFORE_LABEL \
	-nl $AFTER_LABEL \
	-s 

fi

if [ "$MT_CORR" = true ]; then

    echo 'Summarizing results for corrected single iteration ...'
    
    # Outdir
    OUTDIR=${MAINDIR}/single_iteration_corrected

    # File label
    BEFORE=before
    AFTER=gcmt3d_fix

    BEFORE_LABEL=GCMT
    AFTER_LABEL=GCMT3DX

    # Fix database
    if [ "$PICKLES" = true ]; then
	echo Creating the database pickles ...
	gcmt3d-plot-measurement-histograms \
	    -d $INVDATABASE -o $OUTDIR -a $AFTER -b $BEFORE -m dlna
    fi

    echo Plotting ...
    # dlnA
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m dlna
    # Chi
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m chi
    # tshift
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR -a $AFTER_LABEL -b $BEFORE_LABEL -m time_shift

    # Catalog comparison
    compare-catalogs \
	-o $CATALOGS/gcmt.pkl \
	-n $CATALOGS/gcmt3d_fix.pkl \
	-d $OUTDIR \
	-w \
	-ol $BEFORE_LABEL \
	-nl $AFTER_LABEL \
	-s

fi

# -------------------------- Iterative Depth inversion --------------------------------

if [ "$DEPTH" = true ]; then 

    echo 'Summarizing results for depth inversion ...'
    
    # Set vairables
    INVDATABASE=/gpfs/alpine/geo111/scratch/lsawade/database_depth_hypo_damping_2
    SI_INVDATABASE=/gpfs/alpine/geo111/scratch/lsawade/testdatabase_mt_si_hypo_damping_2

    # # Outdir
    OUTDIR=${MAINDIR}/iterative

    # File label
    BEFORE=before
    AFTER=after

    BEFORE_LABEL=GCMT3D
    AFTER_LABEL=GCMT3D+

    # Fix database
    if [ "$PICKLES" = true ]; then
	echo Creating the database pickles ...
	gcmt3d-plot-measurement-histograms \
	    -d $INVDATABASE -o $OUTDIR -a $AFTER -b $BEFORE -m dlna
    fi

    echo Plotting ...
    # dlnA
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m dlna
    # Chi
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m chi
    # tshift
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m time_shift

    # Catalog comparison
    compare-catalogs \
	-o $CATALOGS/gcmt3d.pkl \
	-n $CATALOGS/gcmt3d+.pkl \
	-d $OUTDIR \
	-w \
	-ol $BEFORE_LABEL \
	-nl $AFTER_LABEL \
	-s 

fi



if [ "$DEPTH_CORR" = true ]; then

    echo 'Summarizing results for corrected depth inversion ...'
    
    # Outdir
    OUTDIR=${MAINDIR}/iterative_corrected

    # File label
    BEFORE=before
    AFTER=gcmt3d+_fix

    BEFORE_LABEL=GCMT3D+
    AFTER_LABEL=GCMT3D+-X

    # Fix database
    if [ "$PICKLES" = true ]; then
	echo Creating the database pickles ...
	gcmt3d-plot-measurement-histograms -d $INVDATABASE -o $OUTDIR -a $AFTER -b $BEFORE -m dlna
    fi

    echo Plotting ...
    # dlnA
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m dlna
    # Chi
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m chi
    # shift
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR/database_measurement_$BEFORE.pkl \
	$OUTDIR/database_measurement_$AFTER.pkl \
	-o $OUTDIR \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m time_shift

    # Catalog comparison
    compare-catalogs \
	-o $CATALOGS/gcmt3d+.pkl \
	-n $CATALOGS/gcmt3d+_fix.pkl \
	-d $OUTDIR \
	-w \
	-ol $BEFORE_LABEL \
	-nl $AFTER_LABEL \
	-s 

fi
# -------------------------- Final  --------------------------------

if [ "$FINAL" = true ]; then
    
    echo 'Summarizing results for final results ...'
    
    # Set vairables
    INVDATABASE=/gpfs/alpine/geo111/scratch/lsawade/database_depth_hypo_damping_2
    SI_INVDATABASE=/gpfs/alpine/geo111/scratch/lsawade/testdatabase_mt_si_hypo_damping_2

    OUTDIR_SI=${MAINDIR}/single_iteration
    OUTDIR_ITER_CORR=${MAINDIR}/iterative_corrected

    # Make figures for final comparison
    OUTDIRFINAL=${MAINDIR}/final

    # Make figures with starting solutions.
    OUTDIR_START=${MAINDIR}/start

    # File label
    BEFORE=before
    AFTER=gcmt3d+_fix

    BEFORE_LABEL=GCMT
    AFTER_LABEL=GCMT3D+X

    # Plot the starting
    echo Plotting from past pickles
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR_SI/database_measurement_$BEFORE.pkl \
	$OUTDIR_ITER_CORR/database_measurement_$AFTER.pkl \
	-o $OUTDIR_START \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m dlna chi time_shift \
	--no-after


    # Plot the final
    echo Plotting from past pickles
    gcmt3d-plot-measurement-histograms-pkl \
	$OUTDIR_SI/database_measurement_$BEFORE.pkl \
	$OUTDIR_ITER_CORR/database_measurement_$AFTER.pkl \
	-o $OUTDIRFINAL \
	-a $AFTER_LABEL \
	-b $BEFORE_LABEL \
	-m dlna chi time_shift

    # Catalog comparison
    compare-catalogs \
	-o $CATALOGS/gcmt.pkl \
	-n $CATALOGS/gcmt3d+_fix.pkl \
	-d $OUTDIRFINAL \
	-w \
	-ol $BEFORE_LABEL \
	-nl $AFTER_LABEL \
	-s 

fi

