#!/bin/bash
#SBATCH -N1
#SBATCH -t02:00:00
#SBATCH -A GEO111 
#SBATCH -o copylog-%J.txt

longprocess() {
    # Sleep up to 14 seconds
    sleep $((RANDOM % 4))
    

    # Randomly exit with 0 or 1
    exit $((RANDOM % 2))
}

limit_jobs()
{
   while true; do
      if [ "$(jobs -p | wc -l)" -lt "$1" ]; then break; fi
      sleep 0.1 # Sleep for half a second
   done
}


# just in case
ulimit -s unlimited

# load things
module purge
module load emacs python/3.7-anaconda3
. /sw/andes/python/3.7/anaconda-base/etc/profile.d/conda.sh


conda activate lwsspy_andes

# DATA=/gpfs/alpine/geo111/scratch/lsawade/DATA_DATABASE
EVENTDIR=/ccs/home/lsawade/DAMPING_EVENTS

# GCMT3D
SRC_DATABASE=/gpfs/alpine/geo111/scratch/lsawade/testdatabase_mt_si_hypo_damping_2
DES_DATABASE=/gpfs/alpine/geo111/scratch/lsawade/DAMPING/d1000000

# GCMT3D+
# SRC_DATABASE=/gpfs/alpine/geo111/scratch/lsawade/database_depth_hypo_damping_2
# DES_DATABASE=/gpfs/alpine/geo111/scratch/lsawade/gcmt3d+



# Create the database directory if it doesn't exist
[[ -d ${DES_DATABASE} ]] || mkdir ${DES_DATABASE}


for EVENT in $(ls ${EVENTDIR})
do
    echo "Submitting ${EVENT}: ${SRC_DATABASE} -> ${DES_DATABASE}"
    # srun --exclusive -n 1
    rsync -a \
	  --exclude="synt" \
	  ${SRC_DATABASE}/${EVENT}/ \
	  ${DES_DATABASE}/${EVENT} &

    pids+=("$!")
    cmts+=("${EVENT}")

    limit_jobs 16
    
done




for i in ${!pids[@]}; do

    if wait ${pids[$i]}; then

	echo ${cmts[$i]} SUCCESS

    else

	echo ${cmts[$i]} FAIL

    fi

done
